==> ogre-13.1.1-1-x86_64.pkg.tar.zst: usr/share/doc/OGRE/api/html/class_ogre_1_1_render_system_capabilities.js <==
var class_ogre_1_1_render_system_capabilities =
[
    [ "ShaderProfiles", "class_ogre_1_1_render_system_capabilities.html#a44a272cf319952bf421faa15a473dd24", null ],
    [ "RenderSystemCapabilities", "class_ogre_1_1_render_system_capabilities.html#a04d9002874f93e33c1c19b77981619b9", null ],
    [ "setDriverVersion", "class_ogre_1_1_render_system_capabilities.html#a651a8439d689ee0596ae7433df8ef593", null ],
    [ "parseDriverVersionFromString", "class_ogre_1_1_render_system_capabilities.html#aa4bceb481ecb9e3cf149f56d6195211f", null ],
    [ "getDriverVersion", "class_ogre_1_1_render_system_capabilities.html#a8fd951ef5aa2b48b18ca65419cfb2c46", null ],
    [ "getVendor", "class_ogre_1_1_render_system_capabilities.html#aa00b7c6fb7b39b666fe29ab2b1f61cf8", null ],
    [ "setVendor", "class_ogre_1_1_render_system_capabilities.html#acea58e6dfa194db2dc129927553c2ab5", null ],
    [ "parseVendorFromString", "class_ogre_1_1_render_system_capabilities.html#a3b461142b8f84350448d6f600c043a65", null ],
    [ "vendorFromString", "class_ogre_1_1_render_system_capabilities.html#a413b71be5793f84bf93f5613b8e508de", null ],
    [ "vendorToString", "class_ogre_1_1_render_system_capabilities.html#a40f9afcc9f9c66c29adddbaf82047b89", null ],
    [ "isDriverOlderThanVersion", "class_ogre_1_1_render_system_capabilities.html#a98a43c931aabeab52ab00918f423b5bb", null ],
    [ "setNumTextureUnits", "class_ogre_1_1_render_system_capabilities.html#a30d60525e67ed5f91b6cbd6237bf6d59", null ],
    [ "setStencilBufferBitDepth", "class_ogre_1_1_render_system_capabilities.html#a8e94964a9e870f2abae39d60ca481222", null ],
    [ "setNumMultiRenderTargets", "class_ogre_1_1_render_system_capabilities.html#ae71df2e605b37bc04a8ea19ac783aff8", null ],
    [ "setNumVertexAttributes", "class_ogre_1_1_render_system_capabilities.html#a879d86334d0a1a081412483e537669d7", null ],
    [ "getNumVertexAttributes", "class_ogre_1_1_render_system_capabilities.html#aff7a6b99112aad2655521689f807ac4d", null ],
    [ "getNumTextureUnits", "class_ogre_1_1_render_system_capabilities.html#a98712a93d0e491ad1b01eee1ec96a751", null ],
    [ "getStencilBufferBitDepth", "class_ogre_1_1_render_system_capabilities.html#aef9d77ec493699878c3c71ded4ffbacc", null ],
    [ "getNumMultiRenderTargets", "class_ogre_1_1_render_system_capabilities.html#a6073b0139d263b7750a8117b4af812fe", null ],
    [ "isCapabilityRenderSystemSpecific", "class_ogre_1_1_render_system_capabilities.html#a5736f84bb4f082f39a564b09b82e6e50", null ],
    [ "setCapability", "class_ogre_1_1_render_system_capabilities.html#ae4d12b08dc193773222f9938c54d452c", null ],
    [ "unsetCapability", "class_ogre_1_1_render_system_capabilities.html#ad01ce2fbf726de817cb34bbc66cf946c", null ],
    [ "hasCapability", "class_ogre_1_1_render_system_capabilities.html#ad40e2afdc51576b42881ed4d1992b076", null ],
    [ "addShaderProfile", "class_ogre_1_1_render_system_capabilities.html#afdc1e7ba62cb1f222fcf23c9290a55d5", null ],
    [ "removeShaderProfile", "class_ogre_1_1_render_system_capabilities.html#a910a1e3eaa64e0571760911042a5aff8", null ],
    [ "isShaderProfileSupported", "class_ogre_1_1_render_system_capabilities.html#a210c5e1f5feed4782887932fabb8d72d", null ],
    [ "getSupportedShaderProfiles", "class_ogre_1_1_render_system_capabilities.html#a11ea4ae1018fa18e6192a0898251b5d1", null ],
    [ "getVertexProgramConstantFloatCount", "class_ogre_1_1_render_system_capabilities.html#aed5c5d2113ff80d8ba60defbfe4735ac", null ],
    [ "getVertexProgramConstantIntCount", "class_ogre_1_1_render_system_capabilities.html#ac52999b8bf182bc3c0c8418e67dd5791", null ],
    [ "getVertexProgramConstantBoolCount", "class_ogre_1_1_render_system_capabilities.html#a7fc7edb1a1e7618305ba2d0545db2337", null ],
    [ "getGeometryProgramConstantFloatCount", "class_ogre_1_1_render_system_capabilities.html#a153b04f5cfa0d4b3d5e885e84b01428c", null ],
    [ "getGeometryProgramConstantIntCount", "class_ogre_1_1_render_system_capabilities.html#a355623f05fb31cb88c76b169a7acafc8", null ],
    [ "getGeometryProgramConstantBoolCount", "class_ogre_1_1_render_system_capabilities.html#aa84ce322b237093dd2ce6dda62100338", null ],
    [ "getFragmentProgramConstantFloatCount", "class_ogre_1_1_render_system_capabilities.html#a10b299503587efb44d55dec8b93fa0fb", null ],
    [ "getFragmentProgramConstantIntCount", "class_ogre_1_1_render_system_capabilities.html#aa0a23a88fad7e3f211fc6d6fb7014b30", null ],
    [ "getFragmentProgramConstantBoolCount", "class_ogre_1_1_render_system_capabilities.html#a0b843991586d5095684f4c8900516d2c", null ],
    [ "setDeviceName", "class_ogre_1_1_render_system_capabilities.html#afcc42f461a80ef4164f44d4b32b95ef7", null ],
    [ "getDeviceName", "class_ogre_1_1_render_system_capabilities.html#a92dc13accfa5b8692079795e92e2a3c2", null ],
    [ "setVertexProgramConstantFloatCount", "class_ogre_1_1_render_system_capabilities.html#a1e7fb39f40db9845caba401dd68b71f0", null ],
    [ "setVertexProgramConstantIntCount", "class_ogre_1_1_render_system_capabilities.html#aca154f790d3d3e17ea63eae71c4809ea", null ],
    [ "setVertexProgramConstantBoolCount", "class_ogre_1_1_render_system_capabilities.html#a5c5748ababf1fed6341974394707af2e", null ],
    [ "setGeometryProgramConstantFloatCount", "class_ogre_1_1_render_system_capabilities.html#a2142d81f74376c692171e6e0f0ecc9de", null ],
    [ "setGeometryProgramConstantIntCount", "class_ogre_1_1_render_system_capabilities.html#a432f2f96f21e38e6b30801545feb4141", null ],
    [ "setGeometryProgramConstantBoolCount", "class_ogre_1_1_render_system_capabilities.html#afae9796c75f5ee522a87b3dbcb2d8385", null ],
    [ "setFragmentProgramConstantFloatCount", "class_ogre_1_1_render_system_capabilities.html#ad5ebcf7fa91d34bbda4d9020b43e3e33", null ],
    [ "setFragmentProgramConstantIntCount", "class_ogre_1_1_render_system_capabilities.html#abc084fe2dda834b7d6b236b7ebd27c47", null ],
    [ "setFragmentProgramConstantBoolCount", "class_ogre_1_1_render_system_capabilities.html#a011eba973fe349f787a621240b23617c", null ],
    [ "setMaxPointSize", "class_ogre_1_1_render_system_capabilities.html#a1af2a1dc2f1ca1f269dac3f2086ce61d", null ],
    [ "getMaxPointSize", "class_ogre_1_1_render_system_capabilities.html#a3f00430fc04e37e98c2fe67c3492179a", null ],
    [ "setNonPOW2TexturesLimited", "class_ogre_1_1_render_system_capabilities.html#aa01343a82a55354a350735ffeb53a237", null ],
    [ "getNonPOW2TexturesLimited", "class_ogre_1_1_render_system_capabilities.html#a230a752e1b5549e91088453d1b9f4404", null ],
    [ "setMaxSupportedAnisotropy", "class_ogre_1_1_render_system_capabilities.html#a35a966598295e070bdd0436bf1584ee8", null ],
    [ "getMaxSupportedAnisotropy", "class_ogre_1_1_render_system_capabilities.html#a494188486896e8f012c5f0d4d80ddb58", null ],
    [ "setNumVertexTextureUnits", "class_ogre_1_1_render_system_capabilities.html#ac413b836ff218b338962cfdbfd8f3abd", null ],
    [ "getNumVertexTextureUnits", "class_ogre_1_1_render_system_capabilities.html#a6c34dc4a0039eac169588624b45bae30", null ],
    [ "setVertexTextureUnitsShared", "class_ogre_1_1_render_system_capabilities.html#a6d3150e03533c65123b4cdc1abf148cf", null ],
    [ "getVertexTextureUnitsShared", "class_ogre_1_1_render_system_capabilities.html#a04970b033a6d022c97ab0c7482b38989", null ],
    [ "setGeometryProgramNumOutputVertices", "class_ogre_1_1_render_system_capabilities.html#a4c910cd9c215dff276f3907f1729df35", null ],
    [ "getGeometryProgramNumOutputVertices", "class_ogre_1_1_render_system_capabilities.html#ae21840ac916791a1894a060173af6088", null ],
    [ "getRenderSystemName", "class_ogre_1_1_render_system_capabilities.html#adb6c8f068a8d39ce7b28ff9daa67ac70", null ],
    [ "setRenderSystemName", "class_ogre_1_1_render_system_capabilities.html#a2dac3b98a92f6f65f73d866f0ed7f329", null ],
    [ "setCategoryRelevant", "class_ogre_1_1_render_system_capabilities.html#a3ed32552ceae783c759ded39cb97c8ae", null ],
    [ "isCategoryRelevant", "class_ogre_1_1_render_system_capabilities.html#a369ff64e76af2c9a7411efae8bdd2de5", null ],
    [ "log", "class_ogre_1_1_render_system_capabilities.html#ad051d88f2236b4142f55b1ff7df135b2", null ],
    [ "setTessellationHullProgramConstantFloatCount", "class_ogre_1_1_render_system_capabilities.html#aa03c40c75a685316dddf71b5307fa3a8", null ],
    [ "setTessellationHullProgramConstantIntCount", "class_ogre_1_1_render_system_capabilities.html#a59b140699a493076ff4c1619a3aeb156", null ],
    [ "setTessellationHullProgramConstantBoolCount", "class_ogre_1_1_render_system_capabilities.html#ace06450b136e411ffe4004f47e762972", null ],
    [ "getTessellationHullProgramConstantFloatCount", "class_ogre_1_1_render_system_capabilities.html#a50b7bcec6f5cfbff3c38be48d900b295", null ],
    [ "getTessellationHullProgramConstantIntCount", "class_ogre_1_1_render_system_capabilities.html#ae4bf2e8c7e7c0dd50dd823590fb54cf1", null ],
    [ "getTessellationHullProgramConstantBoolCount", "class_ogre_1_1_render_system_capabilities.html#a36654a99a4a4cbb377ef5d8c50fef925", null ],
    [ "setTessellationDomainProgramConstantFloatCount", "class_ogre_1_1_render_system_capabilities.html#a7aaf3bbefa87b16ab9f3a1a990ead875", null ],
    [ "setTessellationDomainProgramConstantIntCount", "class_ogre_1_1_render_system_capabilities.html#ac903169765bb01ec8cff7e4d10a4a47d", null ],
    [ "setTessellationDomainProgramConstantBoolCount", "class_ogre_1_1_render_system_capabilities.html#a4727cefb9fb9159e6a40c0458f99bc84", null ],
    [ "getTessellationDomainProgramConstantFloatCount", "class_ogre_1_1_render_system_capabilities.html#ab2977395361884a260902f6f331145b2", null ],
    [ "getTessellationDomainProgramConstantIntCount", "class_ogre_1_1_render_system_capabilities.html#af5b9ee07961424192087a2eb2a9939b1", null ],
    [ "getTessellationDomainProgramConstantBoolCount", "class_ogre_1_1_render_system_capabilities.html#a15eb29899db4932b69c88543404a8bdb", null ],
    [ "setComputeProgramConstantFloatCount", "class_ogre_1_1_render_system_capabilities.html#aa7710e8231a55cba0fb857160770f23b", null ],
    [ "setComputeProgramConstantIntCount", "class_ogre_1_1_render_system_capabilities.html#a3c5d805807e388c09a95e63fe6b123bd", null ],
    [ "setComputeProgramConstantBoolCount", "class_ogre_1_1_render_system_capabilities.html#ad23bd6a5b18c575c854d0695a7f2f387", null ],
    [ "getComputeProgramConstantFloatCount", "class_ogre_1_1_render_system_capabilities.html#ad568cc4ee02777e5cf192327cba616a7", null ],
    [ "getComputeProgramConstantIntCount", "class_ogre_1_1_render_system_capabilities.html#a83f826c343c0b18d99fcc683ce6fc595", null ],
    [ "getComputeProgramConstantBoolCount", "class_ogre_1_1_render_system_capabilities.html#a97eb6f1cb33c081723a8e86a8e6c5355", null ]
];

==> ogre-14.3.2-2-x86_64.pkg.tar.zst: usr/share/doc/OGRE/api/html/class_ogre_1_1_render_system_capabilities.js <==
var class_ogre_1_1_render_system_capabilities =
[
    [ "ShaderProfiles", "class_ogre_1_1_render_system_capabilities.html#aac30da6e68cf0cf2ca92937efc856834", null ],
    [ "RenderSystemCapabilities", "class_ogre_1_1_render_system_capabilities.html#a04d9002874f93e33c1c19b77981619b9", null ],
    [ "setDriverVersion", "class_ogre_1_1_render_system_capabilities.html#a651a8439d689ee0596ae7433df8ef593", null ],
    [ "parseDriverVersionFromString", "class_ogre_1_1_render_system_capabilities.html#aa4bceb481ecb9e3cf149f56d6195211f", null ],
    [ "getDriverVersion", "class_ogre_1_1_render_system_capabilities.html#a8fd951ef5aa2b48b18ca65419cfb2c46", null ],
    [ "getVendor", "class_ogre_1_1_render_system_capabilities.html#aa00b7c6fb7b39b666fe29ab2b1f61cf8", null ],
    [ "setVendor", "class_ogre_1_1_render_system_capabilities.html#acea58e6dfa194db2dc129927553c2ab5", null ],
    [ "parseVendorFromString", "class_ogre_1_1_render_system_capabilities.html#a3b461142b8f84350448d6f600c043a65", null ],
    [ "vendorFromString", "class_ogre_1_1_render_system_capabilities.html#a413b71be5793f84bf93f5613b8e508de", null ],
    [ "vendorToString", "class_ogre_1_1_render_system_capabilities.html#a40f9afcc9f9c66c29adddbaf82047b89", null ],
    [ "isDriverOlderThanVersion", "class_ogre_1_1_render_system_capabilities.html#a98a43c931aabeab52ab00918f423b5bb", null ],
    [ "setNumTextureUnits", "class_ogre_1_1_render_system_capabilities.html#a30d60525e67ed5f91b6cbd6237bf6d59", null ],
    [ "setStencilBufferBitDepth", "class_ogre_1_1_render_system_capabilities.html#a8e94964a9e870f2abae39d60ca481222", null ],
    [ "setNumMultiRenderTargets", "class_ogre_1_1_render_system_capabilities.html#ae71df2e605b37bc04a8ea19ac783aff8", null ],
    [ "setNumVertexAttributes", "class_ogre_1_1_render_system_capabilities.html#a879d86334d0a1a081412483e537669d7", null ],
    [ "getNumVertexAttributes", "class_ogre_1_1_render_system_capabilities.html#aff7a6b99112aad2655521689f807ac4d", null ],
    [ "getNumTextureUnits", "class_ogre_1_1_render_system_capabilities.html#a98712a93d0e491ad1b01eee1ec96a751", null ],
    [ "getStencilBufferBitDepth", "class_ogre_1_1_render_system_capabilities.html#aef9d77ec493699878c3c71ded4ffbacc", null ],
    [ "getNumMultiRenderTargets", "class_ogre_1_1_render_system_capabilities.html#a6073b0139d263b7750a8117b4af812fe", null ],
    [ "isCapabilityRenderSystemSpecific", "class_ogre_1_1_render_system_capabilities.html#a5736f84bb4f082f39a564b09b82e6e50", null ],
    [ "setCapability", "class_ogre_1_1_render_system_capabilities.html#ae4d12b08dc193773222f9938c54d452c", null ],
    [ "unsetCapability", "class_ogre_1_1_render_system_capabilities.html#ad01ce2fbf726de817cb34bbc66cf946c", null ],
    [ "hasCapability", "class_ogre_1_1_render_system_capabilities.html#ad40e2afdc51576b42881ed4d1992b076", null ],
    [ "addShaderProfile", "class_ogre_1_1_render_system_capabilities.html#afdc1e7ba62cb1f222fcf23c9290a55d5", null ],
    [ "removeShaderProfile", "class_ogre_1_1_render_system_capabilities.html#a910a1e3eaa64e0571760911042a5aff8", null ],
    [ "isShaderProfileSupported", "class_ogre_1_1_render_system_capabilities.html#a210c5e1f5feed4782887932fabb8d72d", null ],
    [ "getSupportedShaderProfiles", "class_ogre_1_1_render_system_capabilities.html#a11ea4ae1018fa18e6192a0898251b5d1", null ],
    [ "getConstantFloatCount", "class_ogre_1_1_render_system_capabilities.html#adc23596859d446848f4b5cded6a36e18", null ],
    [ "setDeviceName", "class_ogre_1_1_render_system_capabilities.html#afcc42f461a80ef4164f44d4b32b95ef7", null ],
    [ "getDeviceName", "class_ogre_1_1_render_system_capabilities.html#a92dc13accfa5b8692079795e92e2a3c2", null ],
    [ "setVertexProgramConstantFloatCount", "class_ogre_1_1_render_system_capabilities.html#a1e7fb39f40db9845caba401dd68b71f0", null ],
    [ "setGeometryProgramConstantFloatCount", "class_ogre_1_1_render_system_capabilities.html#a2142d81f74376c692171e6e0f0ecc9de", null ],
    [ "setFragmentProgramConstantFloatCount", "class_ogre_1_1_render_system_capabilities.html#ad5ebcf7fa91d34bbda4d9020b43e3e33", null ],
    [ "setMaxPointSize", "class_ogre_1_1_render_system_capabilities.html#a1af2a1dc2f1ca1f269dac3f2086ce61d", null ],
    [ "getMaxPointSize", "class_ogre_1_1_render_system_capabilities.html#a3f00430fc04e37e98c2fe67c3492179a", null ],
    [ "setNonPOW2TexturesLimited", "class_ogre_1_1_render_system_capabilities.html#aa01343a82a55354a350735ffeb53a237", null ],
    [ "getNonPOW2TexturesLimited", "class_ogre_1_1_render_system_capabilities.html#a230a752e1b5549e91088453d1b9f4404", null ],
    [ "setMaxSupportedAnisotropy", "class_ogre_1_1_render_system_capabilities.html#a35a966598295e070bdd0436bf1584ee8", null ],
    [ "getMaxSupportedAnisotropy", "class_ogre_1_1_render_system_capabilities.html#a494188486896e8f012c5f0d4d80ddb58", null ],
    [ "setNumVertexTextureUnits", "class_ogre_1_1_render_system_capabilities.html#ac413b836ff218b338962cfdbfd8f3abd", null ],
    [ "getNumVertexTextureUnits", "class_ogre_1_1_render_system_capabilities.html#a6c34dc4a0039eac169588624b45bae30", null ],
    [ "setGeometryProgramNumOutputVertices", "class_ogre_1_1_render_system_capabilities.html#a4c910cd9c215dff276f3907f1729df35", null ],
    [ "getGeometryProgramNumOutputVertices", "class_ogre_1_1_render_system_capabilities.html#ae21840ac916791a1894a060173af6088", null ],
    [ "getRenderSystemName", "class_ogre_1_1_render_system_capabilities.html#adb6c8f068a8d39ce7b28ff9daa67ac70", null ],
    [ "setRenderSystemName", "class_ogre_1_1_render_system_capabilities.html#a2dac3b98a92f6f65f73d866f0ed7f329", null ],
    [ "setCategoryRelevant", "class_ogre_1_1_render_system_capabilities.html#a3ed32552ceae783c759ded39cb97c8ae", null ],
    [ "isCategoryRelevant", "class_ogre_1_1_render_system_capabilities.html#a369ff64e76af2c9a7411efae8bdd2de5", null ],
    [ "log", "class_ogre_1_1_render_system_capabilities.html#ad051d88f2236b4142f55b1ff7df135b2", null ],
    [ "setComputeProgramConstantFloatCount", "class_ogre_1_1_render_system_capabilities.html#aa7710e8231a55cba0fb857160770f23b", null ],
    [ "setTessellationDomainProgramConstantFloatCount", "class_ogre_1_1_render_system_capabilities.html#a7aaf3bbefa87b16ab9f3a1a990ead875", null ],
    [ "setTessellationHullProgramConstantFloatCount", "class_ogre_1_1_render_system_capabilities.html#aa03c40c75a685316dddf71b5307fa3a8", null ]
];
